@@ -26,6 +26,7 @@
 #include <QMap>
 #include <QResource>
 #include <QSet>
+#include <QTimer>
 
 #include <private/qguiapplication_p.h>
 #include <qpa/qplatformtheme.h>
@@ -41,7 +42,17 @@ Q_GLOBAL_STATIC(QString, _themeOverride)
 
 #if !USE_BreezeIcons
 
-// on Android we are marked as porting AID, don't mess with theming
+// on Android icon theme loading works differently and is managed by code in Kirigami
+// so don't actually touch anything icon-related here
+static void initThemeHelper()
+{
+    // postpone until QGuiApplication applies initial palette
+    QTimer::singleShot(0, [] {
+        // follow the system color, construct the global manager for that
+        (void)KColorSchemeManager::instance();
+    });
+}
+
 void KIconTheme::initTheme()
 {
 }
@@ -100,10 +111,12 @@ static void initThemeHelper()
     *_themeOverride() = themeToUse;
     qCDebug(KICONTHEMES) << "KIconTheme::initTheme() enforces the icon theme:" << themeToUse;
 
-    // follow the system color, construct the global manager for that
-    (void)KColorSchemeManager::instance();
+    // postpone until QGuiApplication applies initial palette
+    QTimer::singleShot(0, [] {
+        // follow the system color, construct the global manager for that
+        (void)KColorSchemeManager::instance();
+    });
 }
-Q_COREAPP_STARTUP_FUNCTION(initThemeHelper)
 
 void KIconTheme::initTheme()
 {
@@ -126,6 +139,8 @@ void KIconTheme::initTheme()
 
 #endif
 
+Q_COREAPP_STARTUP_FUNCTION(initThemeHelper)
+
 class KIconThemeDir;
 class KIconThemePrivate
 {
@@ -427,7 +442,7 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
         KConfigGroup cg(d->sharedConfig, dirName);
         for (const auto &themeDir : std::as_const(themeDirs)) {
             const QString currentDir(themeDir + dirName + QLatin1Char('/'));
-            if (!addedDirs.contains(currentDir) && QDir(currentDir).exists()) {
+            if (!addedDirs.contains(currentDir) && QFileInfo::exists(currentDir)) {
                 addedDirs.insert(currentDir);
                 KIconThemeDir *dir = new KIconThemeDir(themeDir, dirName, cg);
                 if (dir->isValid()) {
@@ -737,7 +752,7 @@ KIconThemeDir::KIconThemeDir(const QString &basedir, const QString &themedir, co
         return;
     }
 
-    QString tmp = config.readEntry(QStringLiteral("Context"));
+    QString tmp = config.readEntry("Context", QString());
     if (tmp == QLatin1String("Devices")) {
         mContext = KIconLoader::Device;
     } else if (tmp == QLatin1String("MimeTypes")) {
@@ -774,7 +789,7 @@ KIconThemeDir::KIconThemeDir(const QString &basedir, const QString &themedir, co
         qCDebug(KICONTHEMES) << "Invalid Context=" << tmp << "line for icon theme: " << constructFileName(QString());
         return;
     }
-    tmp = config.readEntry(QStringLiteral("Type"), QStringLiteral("Threshold"));
+    tmp = config.readEntry("Type", QStringLiteral("Threshold"));
     if (tmp == QLatin1String("Fixed")) {
         mType = KIconLoader::Fixed;
     } else if (tmp == QLatin1String("Scalable")) {
@@ -786,10 +801,10 @@ KIconThemeDir::KIconThemeDir(const QString &basedir, const QString &themedir, co
         return;
     }
     if (mType == KIconLoader::Scalable) {
-        mMinSize = config.readEntry(QStringLiteral("MinSize"), mSize);
-        mMaxSize = config.readEntry(QStringLiteral("MaxSize"), mSize);
+        mMinSize = config.readEntry("MinSize", mSize);
+        mMaxSize = config.readEntry("MaxSize", mSize);
     } else if (mType == KIconLoader::Threshold) {
-        mThreshold = config.readEntry(QStringLiteral("Threshold"), 2);
+        mThreshold = config.readEntry("Threshold", 2);
     }
     mbValid = true;
 }
